@@ -46,7 +46,7 @@ class TestSqlToSlackApiFileOperator:
     @mock.patch("airflow.providers.slack.transfers.sql_to_slack.BaseSqlToSlackOperator._get_query_results")
     @mock.patch("airflow.providers.slack.transfers.sql_to_slack.SlackHook")
     @pytest.mark.parametrize(
-        "filename,df_method",
+        ("filename", "df_method"),
         [
             ("awesome.json", "to_json"),
             ("awesome.json.zip", "to_json"),
@@ -60,7 +60,7 @@ class TestSqlToSlackApiFileOperator:
     @pytest.mark.parametrize("initial_comment", [None, "Test Comment"])
     @pytest.mark.parametrize("title", [None, "Test File Title"])
     @pytest.mark.parametrize(
-        "slack_op_kwargs, hook_extra_kwargs",
+        ("slack_op_kwargs", "hook_extra_kwargs"),
         [
             pytest.param(
                 {},
